@@ -1,5 +1,6 @@
 from dataclasses import asdict, dataclass
 from logging import Logger
+import aiohttp
 from aiokafka import AIOKafkaProducer
 
 from async_tools import AsyncOnStart, AsyncOnStop
@@ -14,6 +15,7 @@ logger = Logger(__name__)
 class NotificationConnector(AsyncOnStart, AsyncOnStop):
     @dataclass
     class Config:
+        url: str
         address: str
         max_request_size: int
         topic: str
@@ -29,6 +31,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
     def __init__(self, config: Config, context: Context) -> None:
         self._config = config
         self._context = context
+        self._http_client = aiohttp.ClientSession()
 
     async def _on_start(self) -> None:
         self._producer = AIOKafkaProducer(
@@ -50,3 +53,16 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
         except Exception as exc:
             logger.error(f'write to kafka channel "{self._config.topic}" failed, error: {exc}')
             return False
+
+    async def mark_notification_as_read_internal(self, source_type: str, notification_ids: list[int]) -> None:
+        logger.debug(f'mark notification as read: {source_type}, {notification_ids}')
+        async with self._http_client.post(
+            f'{self._config.url}/v1/mark_notification_as_read_internal',
+            json={
+                'source_type': source_type,
+                'notification_ids': notification_ids,
+            },
+        ) as response:
+            logger.debug(f'mark notification as read done, status: {response.status}')
+            response.raise_for_status()
+            return await response.json()
